// This file is common to the XML Moo Database browser and Moo Canada's IDE.

// Constructor
function Tab(newname) {
  this.name = newname;
}

Tab.prototype.tabNode = null;
Tab.prototype.contentNode = null;

Tab.prototype.init = function() {
  this.tabNode = document.getElementById("tab_" + this.name);
  this.contentNode = document.getElementById("content_" + this.name);
  // Register the tab-switching function on the onclick hook.
  if (this.tabNode.onclick) {
    // Preserve any existing code.
    this.oldOnClick = this.tabNode.onclick;
  }
  this.tabNode.onclick = Tab.Click;
}

Tab.Click = function() {
  // When the user clicks a tab, switch the visible pane.
  // First, deselect all tabs and hide all panes.
  var tabObject;
  for (var x in Tab.List) {
    tabObject = Tab.List[x];
    if (tabObject.tabNode === this) {
      tabObject.tabNode.className = "tabon";
      tabObject.contentNode.style.display = "block";
      // Execute any previously defined onclick code.
      if (tabObject.oldOnClick) {
        tabObject.oldOnClick();
      }
    } else {
      tabObject.tabNode.className = "taboff";
      tabObject.contentNode.style.display = "none";
    }
  }
}

// Ordered associative list of all tabs on a page.
Tab.List = {};

// Return the name of the tab which is currently selected.
Tab.Selected = function() {
  for (var x in Tab.List) {
    if (Tab.List[x].tabNode.className == "tabon") {
      return Tab.List[x].name;
    }
  }
  return "";
}

Tab.RowHeight = 0;

Tab.OnLoad = function() {
  setTimeout('Tab.ReflowInit()',1);
  // Register the reflow function on the onresize hook.
  if (window.onresize) {
    // Preserve any existing code.
    Tab.OldOnResize = window.onresize;
  }
  window.onresize = Tab.Reflow;
  // Now that the DOM exists, initialize each tab.
  for (var x in Tab.List) {
    Tab.List[x].init();
  }  
}

Tab.ReflowInit = function() {
  // Memorize the height of the tab row.
  for (var x in Tab.List) {
    Tab.RowHeight = Tab.List[x].tabNode.offsetHeight;
    break;
  }
  if (!Tab.RowHeight) {
    // Race condition?
    setTimeout('Tab.ReflowInit()',500);
    return;  
  }
  Tab.Reflow();
}

Tab.Reflow = function() {
  // Manually set the height of the scrolling content to fill the window,
  // minus the height of the tab row.
  if (!Tab.RowHeight) {
    // Hasn't been initialised yet.
    return;
  }
  var height = (window.innerHeight || document.body.offsetHeight) - Tab.RowHeight;
  // Subtract off the padding-top and padding-bottom as definied in the style sheet.
  height = height - 2 - 5;
  height = Math.max(height, 10);
  for (var x in Tab.List) {
    Tab.List[x].contentNode.style.height = height+"px";
  }
  // Execute any previously defined onresize code.
  if (Tab.OldOnResize) {
    Tab.OldOnResize();
  }
}

Tab.Create = function() {
  for (var x = 0; x < arguments.length; x++) {
    Tab.List[arguments[x]] = new Tab(arguments[x]);
  }
}
